"use client"

import { TrendingUp } from "lucide-react"
import { Bar, BarChart, XAxis, YAxis } from "recharts"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/Components/ui/card"
import { type ChartConfig, ChartContainer, ChartTooltip, ChartTooltipContent } from "@/Components/ui/chart"

interface SiteData {
  name: string;
  total_revenue: number;
}

interface DataBarChartProps {
  data: SiteData[];
}

export function DataBarChart({ data }: DataBarChartProps) {
  // Transform the data to match your original chart format
  const chartData = data.map((site, index) => ({
    browser: site.name,
    visitors: site.total_revenue,
    fill: `hsl(${index * 50}, 84.2%, 60.2%)`, // Assigning unique colors
  }));

  // Create config dynamically based on site names
  const chartConfig = {
    visitors: {
      label: "Revenue ($)",
    },
    ...data.reduce((acc, site, index) => ({
      ...acc,
      [site.name]: {
        label: site.name,
        fill: `hsl(${index * 50}, 84.2%, 60.2%)`, // Assigning unique colors
    }
    }), {})
  } satisfies ChartConfig

  return (
    <Card className="bg-transparent border-none shadow-none">
      <CardHeader className="lg:p-6 p-0">
        <CardTitle className="text-green-600 text-2xl font-bold">Site Revenue with Bar Chart</CardTitle>
        <CardDescription>Revenue by site</CardDescription>
      </CardHeader>
      <CardContent className="lg:p-6 p-0">
        <ChartContainer config={chartConfig}>
          <BarChart
            accessibilityLayer
            data={chartData}
            layout="vertical"
            margin={{
                left: 20, // Increased left margin for longer names
                right: 20,
                top: 5,
                bottom: 5,
              }}
          >
            <YAxis
              dataKey="browser"
              type="category"
              tickLine={false}
              tickMargin={10}
              axisLine={false}
              width={100}
              tickFormatter={(value) => chartConfig[value as keyof typeof chartConfig]?.label || value}
            />
            <XAxis
              dataKey="visitors"
              type="number"
              tickFormatter={(value) => `$${value.toLocaleString()}`}
            />
            <ChartTooltip
              cursor={false}
              content={<ChartTooltipContent
                hideLabel
              />}
            />
            <Bar dataKey="visitors" layout="vertical" radius={5} />
          </BarChart>
        </ChartContainer>
      </CardContent>
      <CardFooter className="flex-col items-start gap-2 text-sm lg:p-6 p-0">
        <div className="flex gap-2 font-medium leading-none">
          Total {data.length} sites <TrendingUp className="h-4 w-4" />
        </div>
        <div className="leading-none text-muted-foreground">
          Showing revenue for all sites
        </div>
      </CardFooter>
    </Card>
  )
}
